@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     CEStateType,
@@ -80,24 +80,33 @@ class Exceptions:
     ServerException: Type[BotocoreClientError]
 
 
-class BatchClient:
+class BatchClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        BatchClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#can_paginate)
         """
 
     def cancel_job(self, *, jobId: str, reason: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.cancel_job)
+        Cancels a job in an AWS Batch job queue.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.cancel_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#cancel_job)
         """
 
@@ -112,7 +121,9 @@ class BatchClient:
         tags: Dict[str, str] = None
     ) -> CreateComputeEnvironmentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.create_compute_environment)
+        Creates an AWS Batch compute environment.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.create_compute_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#create_compute_environment)
         """
 
@@ -126,25 +137,33 @@ class BatchClient:
         tags: Dict[str, str] = None
     ) -> CreateJobQueueResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.create_job_queue)
+        Creates an AWS Batch job queue.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.create_job_queue)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#create_job_queue)
         """
 
     def delete_compute_environment(self, *, computeEnvironment: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.delete_compute_environment)
+        Deletes an AWS Batch compute environment.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.delete_compute_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#delete_compute_environment)
         """
 
     def delete_job_queue(self, *, jobQueue: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.delete_job_queue)
+        Deletes the specified job queue.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.delete_job_queue)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#delete_job_queue)
         """
 
     def deregister_job_definition(self, *, jobDefinition: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.deregister_job_definition)
+        Deregisters an AWS Batch job definition.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.deregister_job_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#deregister_job_definition)
         """
 
@@ -156,7 +175,9 @@ class BatchClient:
         nextToken: str = None
     ) -> DescribeComputeEnvironmentsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.describe_compute_environments)
+        Describes one or more of your compute environments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.describe_compute_environments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_compute_environments)
         """
 
@@ -170,7 +191,9 @@ class BatchClient:
         nextToken: str = None
     ) -> DescribeJobDefinitionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.describe_job_definitions)
+        Describes a list of job definitions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.describe_job_definitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_job_definitions)
         """
 
@@ -178,13 +201,17 @@ class BatchClient:
         self, *, jobQueues: List[str] = None, maxResults: int = None, nextToken: str = None
     ) -> DescribeJobQueuesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.describe_job_queues)
+        Describes one or more of your job queues.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.describe_job_queues)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_job_queues)
         """
 
     def describe_jobs(self, *, jobs: List[str]) -> DescribeJobsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.describe_jobs)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.describe_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#describe_jobs)
         """
 
@@ -196,7 +223,9 @@ class BatchClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#generate_presigned_url)
         """
 
@@ -211,13 +240,17 @@ class BatchClient:
         nextToken: str = None
     ) -> ListJobsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.list_jobs)
+        Returns a list of AWS Batch jobs.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.list_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#list_jobs)
         """
 
     def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.list_tags_for_resource)
+        Lists the tags for an AWS Batch resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#list_tags_for_resource)
         """
 
@@ -236,7 +269,9 @@ class BatchClient:
         platformCapabilities: List[PlatformCapabilityType] = None
     ) -> RegisterJobDefinitionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.register_job_definition)
+        Registers an AWS Batch job definition.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.register_job_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#register_job_definition)
         """
 
@@ -246,36 +281,44 @@ class BatchClient:
         jobName: str,
         jobQueue: str,
         jobDefinition: str,
-        arrayProperties: ArrayPropertiesTypeDef = None,
+        arrayProperties: "ArrayPropertiesTypeDef" = None,
         dependsOn: List["JobDependencyTypeDef"] = None,
         parameters: Dict[str, str] = None,
         containerOverrides: "ContainerOverridesTypeDef" = None,
-        nodeOverrides: NodeOverridesTypeDef = None,
+        nodeOverrides: "NodeOverridesTypeDef" = None,
         retryStrategy: "RetryStrategyTypeDef" = None,
         propagateTags: bool = None,
         timeout: "JobTimeoutTypeDef" = None,
         tags: Dict[str, str] = None
     ) -> SubmitJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.submit_job)
+        Submits an AWS Batch job from a job definition.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.submit_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#submit_job)
         """
 
     def tag_resource(self, *, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.tag_resource)
+        Associates the specified tags to a resource with the specified `resourceArn`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#tag_resource)
         """
 
     def terminate_job(self, *, jobId: str, reason: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.terminate_job)
+        Terminates a job in a job queue.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.terminate_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#terminate_job)
         """
 
     def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.untag_resource)
+        Deletes specified tags from an AWS Batch resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#untag_resource)
         """
 
@@ -284,11 +327,13 @@ class BatchClient:
         *,
         computeEnvironment: str,
         state: CEStateType = None,
-        computeResources: ComputeResourceUpdateTypeDef = None,
+        computeResources: "ComputeResourceUpdateTypeDef" = None,
         serviceRole: str = None
     ) -> UpdateComputeEnvironmentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.update_compute_environment)
+        Updates an AWS Batch compute environment.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.update_compute_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#update_compute_environment)
         """
 
@@ -301,7 +346,9 @@ class BatchClient:
         computeEnvironmentOrder: List["ComputeEnvironmentOrderTypeDef"] = None
     ) -> UpdateJobQueueResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Client.update_job_queue)
+        Updates a job queue.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Client.update_job_queue)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/client.html#update_job_queue)
         """
 
@@ -310,7 +357,8 @@ class BatchClient:
         self, operation_name: Literal["describe_compute_environments"]
     ) -> DescribeComputeEnvironmentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Paginator.DescribeComputeEnvironments)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describecomputeenvironmentspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Paginator.DescribeComputeEnvironments)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describecomputeenvironmentspaginator)
         """
 
     @overload
@@ -318,7 +366,8 @@ class BatchClient:
         self, operation_name: Literal["describe_job_definitions"]
     ) -> DescribeJobDefinitionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Paginator.DescribeJobDefinitions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describejobdefinitionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Paginator.DescribeJobDefinitions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describejobdefinitionspaginator)
         """
 
     @overload
@@ -326,11 +375,13 @@ class BatchClient:
         self, operation_name: Literal["describe_job_queues"]
     ) -> DescribeJobQueuesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Paginator.DescribeJobQueues)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describejobqueuespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Paginator.DescribeJobQueues)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#describejobqueuespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/batch.html#Batch.Paginator.ListJobs)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#listjobspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/batch.html#Batch.Paginator.ListJobs)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators.html#listjobspaginator)
         """
